@@ -1,4 +1,3 @@
-
 import pytest
 import json
 from unittest import mock
@@ -20,6 +19,7 @@ YAML_TEST_OUTPUT_FILE = "tests/test-output.yaml"
 JSON_TEST_OUTPUT_FILE = "tests/test-output.json"
 TREE_TEST_OUTPUT_FILE = "tests/test-output.tree"
 
+
 class MockNode:
     def __init__(self, id, name, url, subgroups=mock.MagicMock(), projects=mock.MagicMock(), parent_id=None):
         self.id = id
@@ -35,18 +35,24 @@ class MockNode:
 
 
 class Listable:
-    def __init__(self, list_result, get_result=None):
+    def __init__(self, list_result, get_result=None, archive_result=None):
         self.list_result = list_result
         self.get_result = get_result
+        self.archive_result = archive_result
 
-    def list(self, as_list=False):
-        return [self.list_result]
+    def list(self, as_list=False, archived=None):
+        if archived is None:
+            return [self.list_result, self.archive_result] if self.archive_result is not None else [self.list_result]
+        elif archived is True:
+            return [self.archive_result]
+        else:
+            return [self.list_result]
 
     def get(self, id):
-        if self.get_result is None:
-            return self.list_result
-        else:
+        if self.get_result is not None:
             return self.get_result
+        else:
+            return self.list_result
 
 
 def validate_root(root):
@@ -94,13 +100,34 @@ def create_test_gitlab(monkeypatch, includes=None, excludes=None, in_file=None):
     subgroup_node = MockNode(2, SUBGROUP_NAME, SUBGROUP_URL, projects=projects)
     subgroups = Listable(subgroup_node)
     groups = Listable(MockNode(2, GROUP_NAME, GROUP_URL,
-                              subgroups=subgroups), subgroup_node)
+                               subgroups=subgroups), subgroup_node)
     monkeypatch.setattr(gl.gitlab, "groups", groups)
     return gl
 
+
 def create_test_gitlab_with_toplevel_subgroups(monkeypatch):
     gl = gitlab_tree.GitlabTree(URL, TOKEN, "ssh", "path")
     groups = Listable([MockNode(2, GROUP_NAME, GROUP_URL),
                        MockNode(2, GROUP_NAME, GROUP_URL, parent_id=1)])
     monkeypatch.setattr(gl.gitlab, "groups", groups)
     return gl
+
+
+def create_test_gitlab_with_archived(monkeypatch, includes=None, excludes=None, in_file=None, archived=None):
+    gl = gitlab_tree.GitlabTree(
+        URL, TOKEN, "ssh", "name", includes=includes, excludes=excludes, in_file=in_file, archived=archived)
+    project_node = MockNode(1, PROJECT_NAME, PROJECT_URL)
+    archived_project_node = MockNode(
+        2, "_archived_" + PROJECT_NAME, "_archived_" + PROJECT_URL)
+    projects = Listable(project_node, archive_result=archived_project_node)
+    subgroup_node = MockNode(2, SUBGROUP_NAME, SUBGROUP_URL, projects=projects)
+    archived_subgroup_node = MockNode(
+        2, "_archived_" + SUBGROUP_NAME, "_archived_" + SUBGROUP_URL, projects=projects)
+    subgroups = Listable(subgroup_node, archive_result=archived_subgroup_node)
+    archived_subgroups = Listable(archived_subgroup_node, archive_result=archived_subgroup_node)
+    group_node = MockNode(2, GROUP_NAME, GROUP_URL, subgroups=archived_subgroups)
+    archived_group_node = MockNode(2, "_archived_" + GROUP_NAME, "_archived_" + GROUP_URL, subgroups=archived_subgroups)
+    groups = Listable(group_node, get_result=subgroup_node, archive_result=archived_group_node)
+    monkeypatch.setattr(gl.gitlab, "groups", groups)
+    # gl.print_tree()
+    return gl
